@@ -178,6 +178,7 @@ dictionary = {
     "tuna": [r"tuna"],
     "salmon": [r"\bsalmon\b"],
     "fatty fish": [
+        "herring",
         "eel",
         "trout",
         "arctic char",
@@ -188,22 +189,22 @@ dictionary = {
         "swordfish",
         "shark",
         r"monk[- ]?fish",
-    ],
-    "lean fish": [
-        "herring",
-        "carp",
         "bluefish",
+        "wahoo",
+    ],
+    "lean_fish": [
+        "carp",
         "bonita",
-        "rock bass",
+        "bass",
         "squeteague",
         "catfish",
         "flounder",
         "cod",
+        "skrei",
+        "hake",
+        "hoki",
         "sole",
-        "red snapper",
         "snapper",
-        "bass",
-        "sea bass",
         "perch",
         "haddock",
         "halibut",
@@ -211,7 +212,22 @@ dictionary = {
         "tilapia",
         "swai",
         "whitefish",
-        "fish",
+        r"mahi[ -]?mahi",
+        "barramundi",
+        "char",
+        "trout",
+        "pollock",
+        "cobia",
+        "croaker",
+        "mullet",
+        "rockfish",
+        "whiting",
+        "saury",
+        "plaice",
+        "grenadier",
+        "kingklip",
+        "sanddab",
+        "sandperch",
     ],
     "octopus": ["octopus", "squid", "calamari", r"cuttle[- ]?fish"],
     "crustacean": [
@@ -222,6 +238,8 @@ dictionary = {
         r"cra[wy][- ]?daddy",
         "krill",
         "crab",
+        r"lobsterette?",
+        "langoustine",
         r"shell[- ]?fish",
     ],
     "other seafood": [
@@ -234,6 +252,7 @@ dictionary = {
         r"escargots?",
         r"caviar",
         r"\broe\b",
+        r"barnacles?",
     ],
     "ham": [
         r"mortadella",
@@ -246,6 +265,8 @@ dictionary = {
         "culatello",
         "gammon",
         "serrano",
+        "bresaola",
+        "lomo",
     ],
     "beef": [
         "new york strip",
